@@ -179,11 +179,6 @@ class NodeList(NodeMixIn, base.BaseListCommand):
                'platform_name',
                'online')
 
-    filters = {
-        'environment_id': 'env',
-        'labels': 'labels'
-    }
-
     def get_parser(self, prog_name):
         parser = super(NodeList, self).get_parser(prog_name)
 
@@ -202,13 +197,16 @@ class NodeList(NodeMixIn, base.BaseListCommand):
 
         return parser
 
+    def take_action(self, parsed_args):
+        data = self.client.get_all(
+            environment_id=parsed_args.env, labels=parsed_args.labels)
+        data = data_utils.get_display_data_multi(self.columns, data)
+
+        return (self.columns, data)
+
 
 class NodeShow(NodeMixIn, base.BaseShowCommand):
     """Show info about node with given id."""
-    numa_fields = (
-        'numa_nodes',
-        'supported_hugepages',
-        'distances')
 
     columns = ('id',
                'name',
@@ -232,15 +230,12 @@ class NodeShow(NodeMixIn, base.BaseShowCommand):
                # TODO(romcheg): network_data mostly never fits the screen
                # 'network_data',
                'manufacturer')
-    columns += numa_fields
+    columns += NodeMixIn.numa_fields
 
     def take_action(self, parsed_args):
         data = self.client.get_by_id(parsed_args.id)
-
-        numa_topology = data['meta'].get('numa_topology', {})
-        for key in self.numa_fields:
-            data[key] = numa_topology.get(key)
-
+        numa_topology = self.get_numa_topology_info(data)
+        data.update(numa_topology)
         data = data_utils.get_display_data_single(self.columns, data)
         return self.columns, data
 
@@ -276,10 +271,12 @@ class NodeUpdate(NodeMixIn, base.BaseShowCommand):
 
         updated_node = self.client.update(
             parsed_args.id, **updates)
+        numa_topology = self.get_numa_topology_info(updated_node)
+        updated_node.update(numa_topology)
         updated_node = data_utils.get_display_data_single(
             self.columns, updated_node)
 
-        return (self.columns, updated_node)
+        return self.columns, updated_node
 
 
 class NodeVmsList(NodeMixIn, base.BaseShowCommand):
@@ -331,10 +328,6 @@ class NodeLabelList(NodeMixIn, base.BaseListCommand):
         'label_name',
         'label_value')
 
-    @property
-    def default_sorting_by(self):
-        return ['node_id']
-
     def get_parser(self, prog_name):
         parser = super(NodeLabelList, self).get_parser(prog_name)
 
@@ -350,9 +343,8 @@ class NodeLabelList(NodeMixIn, base.BaseListCommand):
         data = self.client.get_all_labels_for_nodes(
             node_ids=parsed_args.nodes)
         data = data_utils.get_display_data_multi(self.columns, data)
-        data = self._sort_data(parsed_args, data)
 
-        return self.columns, data
+        return (self.columns, data)
 
 
 class NodeLabelSet(NodeMixIn, base.BaseCommand):
